| StepReg-package | R Documentation |
Stepwise regression is a statistical technique used for model selection. This package streamlines stepwise regression analysis by supporting multiple regression types(linear, Cox, logistic, Poisson, Gamma, and negative binomial), incorporating popular selection strategies(forward, backward, bidirectional, and subset), and offering essential metrics. It enables users to apply multiple selection strategies and metrics in a single function call, visualize variable selection processes, and export results in various formats. StepReg offers a data-splitting option to address potential issues with invalid statistical inference and a randomized forward selection option to avoid overfitting. We validated StepReg's accuracy using public datasets within the SAS software environment. For an interactive web interface, users can install the companion 'StepRegShiny' package. The methodology is described in Li et al. (2026) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.32614/RJ-2026-005")}.
Maintainer: Junhui Li junhui.li11@umassmed.edu (ORCID)
Authors:
Kai Hu kai.hu@umassmed.edu
Xiaohuan Lu
Sushmita N Nayak [contributor]
Cesar Bautista Sotelo [contributor]
Michael A Lodato [contributor]
Wenxin Liu
Lihua Julie Zhu
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.